# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/cogneed-ks/services/convert_webm_to_wav.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/cogneed-ks/services/convert_webm_to_wav.proto',
  package='ai.cogneed.cloud.speech.v1',
  syntax='proto3',
  serialized_options=_b('\n\032ai.cogneed.cloud.speech.v1P\001'),
  serialized_pb=_b('\n<cogneed-protos/cogneed-ks/services/convert_webm_to_wav.proto\x12\x1a\x61i.cogneed.cloud.speech.v1\" \n\rDecodeRequest\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"!\n\x0e\x44\x65\x63odeResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x32v\n\x12OpusDecoderService\x12`\n\x07\x63onvert\x12).ai.cogneed.cloud.speech.v1.DecodeRequest\x1a*.ai.cogneed.cloud.speech.v1.DecodeResponseB\x1e\n\x1a\x61i.cogneed.cloud.speech.v1P\x01\x62\x06proto3')
)




_DECODEREQUEST = _descriptor.Descriptor(
  name='DecodeRequest',
  full_name='ai.cogneed.cloud.speech.v1.DecodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.DecodeRequest.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=124,
)


_DECODERESPONSE = _descriptor.Descriptor(
  name='DecodeResponse',
  full_name='ai.cogneed.cloud.speech.v1.DecodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.cloud.speech.v1.DecodeResponse.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=159,
)

DESCRIPTOR.message_types_by_name['DecodeRequest'] = _DECODEREQUEST
DESCRIPTOR.message_types_by_name['DecodeResponse'] = _DECODERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DecodeRequest = _reflection.GeneratedProtocolMessageType('DecodeRequest', (_message.Message,), dict(
  DESCRIPTOR = _DECODEREQUEST,
  __module__ = 'cogneed_protos.cogneed_ks.services.convert_webm_to_wav_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.DecodeRequest)
  ))
_sym_db.RegisterMessage(DecodeRequest)

DecodeResponse = _reflection.GeneratedProtocolMessageType('DecodeResponse', (_message.Message,), dict(
  DESCRIPTOR = _DECODERESPONSE,
  __module__ = 'cogneed_protos.cogneed_ks.services.convert_webm_to_wav_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.cloud.speech.v1.DecodeResponse)
  ))
_sym_db.RegisterMessage(DecodeResponse)


DESCRIPTOR._options = None

_OPUSDECODERSERVICE = _descriptor.ServiceDescriptor(
  name='OpusDecoderService',
  full_name='ai.cogneed.cloud.speech.v1.OpusDecoderService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=161,
  serialized_end=279,
  methods=[
  _descriptor.MethodDescriptor(
    name='convert',
    full_name='ai.cogneed.cloud.speech.v1.OpusDecoderService.convert',
    index=0,
    containing_service=None,
    input_type=_DECODEREQUEST,
    output_type=_DECODERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPUSDECODERSERVICE)

DESCRIPTOR.services_by_name['OpusDecoderService'] = _OPUSDECODERSERVICE

# @@protoc_insertion_point(module_scope)
